@@ -1,3 +1,4 @@
+"""Verbs and Execution Utilities."""
 from .pandas import (
     aggregate_operation_mapping,
     boolean_function_map,
@@ -5,6 +6,7 @@ from .pandas import (
     get_operator,
 )
 from .types import (
+    AsyncType,
     Bin,
     BinStrategy,
     BooleanComparisonOperator,
@@ -26,13 +28,21 @@ from .types import (
     SortDirection,
     Step,
     StringComparisonOperator,
-    Union,
     WindowFunction,
 )
-from .verbs import VerbDetails, VerbInput, VerbManager, load_verbs, verb
-
+from .verbs import (
+    VerbDetails,
+    VerbInput,
+    VerbManager,
+    load_verbs,
+    new_row,
+    parallel_verb,
+    verb,
+)
 
 __all__ = [
+    "AsyncType",
+    "parallel_verb",
     "VerbInput",
     "VerbDetails",
     "verb",
@@ -58,11 +68,11 @@ __all__ = [
     "SetOp",
     "SortDirection",
     "StringComparisonOperator",
-    "Union",
     "WindowFunction",
     "Step",
     "aggregate_operation_mapping",
     "boolean_function_map",
     "filter_df",
     "get_operator",
+    "new_row",
 ]
