@@ -2,8 +2,10 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
+"""Binarize verb implementation."""
+from typing import Any, cast
 
-from typing import List
+import pandas as pd
 
 from datashaper.engine.pandas import filter_df, get_operator
 from datashaper.engine.types import (
@@ -14,13 +16,19 @@ from datashaper.engine.types import (
 )
 from datashaper.engine.verbs.verb_input import VerbInput
 from datashaper.engine.verbs.verbs_mapping import verb
-from datashaper.table_store import TableContainer
+from datashaper.table_store.types import VerbResult, create_verb_result
 
 
 @verb(name="binarize")
 def binarize(
-    input: VerbInput, to: str, column: str, criteria: List, logical: str = "or"
-):
+    input: VerbInput,
+    to: str,
+    column: str,
+    criteria: list,
+    logical: str = "or",
+    **_kwargs: dict,
+) -> VerbResult:
+    """Binarize verb implementation."""
     filter_criteria = [
         Criterion(
             value=arg.get("value", None),
@@ -31,12 +39,12 @@ def binarize(
     ]
     logical_operator = BooleanLogicalOperator(logical)
 
-    input_table = input.get_input()
+    input_table = cast(pd.DataFrame, input.get_input())
 
     filter_result = filter_df(
         input_table, FilterArgs(column, filter_criteria, logical_operator)
     )
     output = input_table
-    output[to] = filter_result.map({True: 1, False: 0}, na_action="ignore")
+    output[to] = filter_result.map(cast(Any, {True: 1, False: 0}), na_action="ignore")
 
-    return TableContainer(table=output)
+    return create_verb_result(output)
