@@ -2,20 +2,21 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
-from typing import List
-
+"""Drop verb implementation."""
 from datashaper.engine.verbs.verbs_mapping import verb
+from datashaper.table_store.types import VerbResult, create_verb_result
 
-from ...table_store import TableContainer
 from .verb_input import VerbInput
 
 
 @verb(name="drop")
 def drop(
     input: VerbInput,
-    columns: List[str],
-):
+    columns: list[str],
+    **_kwargs: dict,
+) -> VerbResult:
+    """Drop verb implementation."""
     output = input.get_input()
     output = output.drop(columns=columns)
 
-    return TableContainer(table=output)
+    return create_verb_result(output)
