@@ -2,21 +2,29 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
+"""Erase verb implementation."""
+from typing import cast
 
-from typing import Union
+import pandas as pd
 
 from datashaper.engine.verbs.verb_input import VerbInput
 from datashaper.engine.verbs.verbs_mapping import verb
-from datashaper.table_store import TableContainer
+from datashaper.table_store.types import VerbResult, create_verb_result
 
 
 @verb(name="erase")
-def erase(input: VerbInput, column: str, value: Union[str, int, float]):
+def erase(
+    input: VerbInput,
+    column: str,
+    value: str | float,
+    **_kwargs: dict,
+) -> VerbResult:
+    """Erase verb implementation."""
     input_table = input.get_input()
-    output = input_table
+    output = cast(pd.DataFrame, input_table)
 
     output[column] = output[column].apply(
         lambda df_value: None if df_value == value else df_value
     )
 
-    return TableContainer(table=output)
+    return create_verb_result(output)
