@@ -2,8 +2,10 @@
 # Copyright (c) Microsoft. All rights reserved.
 # Licensed under the MIT license. See LICENSE file in the project.
 #
+"""Filter verb implementation."""
+from typing import cast
 
-from typing import List
+import pandas as pd
 
 from datashaper.engine.pandas import filter_df, get_operator
 from datashaper.engine.types import (
@@ -14,11 +16,22 @@ from datashaper.engine.types import (
 )
 from datashaper.engine.verbs.verb_input import VerbInput
 from datashaper.engine.verbs.verbs_mapping import verb
-from datashaper.table_store import TableContainer
+from datashaper.table_store.types import (
+    Table,
+    VerbResult,
+    create_verb_result,
+)
 
 
 @verb(name="filter", treats_input_tables_as_immutable=True)
-def filter(input: VerbInput, column: str, criteria: List, logical: str = "or"):
+def filter_verb(
+    input: VerbInput,
+    column: str,
+    criteria: list,
+    logical: str = "or",
+    **_kwargs: dict,
+) -> VerbResult:
+    """Filter verb implementation."""
     filter_criteria = [
         Criterion(
             value=arg.get("value", None),
@@ -28,13 +41,13 @@ def filter(input: VerbInput, column: str, criteria: List, logical: str = "or"):
         for arg in criteria
     ]
     logical_operator = BooleanLogicalOperator(logical)
-    input_table = input.get_input()
+    input_table = cast(pd.DataFrame, input.get_input())
 
     filter_index = filter_df(
         input_table, FilterArgs(column, filter_criteria, logical_operator)
     )
-
-    idx = filter_index[filter_index == True].index  # noqa: E712
+    sub_idx = filter_index == True  # noqa: E712
+    idx = filter_index[sub_idx].index  # type: ignore
     output = input_table[input_table.index.isin(idx)].reset_index(drop=True)
 
-    return TableContainer(table=output)
+    return create_verb_result(cast(Table, output))
