@@ -3,12 +3,24 @@
 # Licensed under the MIT license. See LICENSE file in the project.
 #
 """Contains the definition for the ExecutionNode type."""
-from typing import Any, Optional, Union
-
 from dataclasses import dataclass, field
 
-from datashaper.engine.verbs import VerbDetails
-from datashaper.table_store import TableContainer
+from datashaper.engine.verbs.types import VerbDetails
+
+
+@dataclass
+class InputBinding:
+    """A binding specification to an input node."""
+
+    node: str
+    """The input node id."""
+
+    output: str | None = None
+    """The output name to bind to. Default Output if None"""
+
+
+"""A workflow input specification"""
+WorkflowInput = InputBinding | str
 
 
 @dataclass
@@ -24,11 +36,8 @@ class ExecutionNode:
     verb: VerbDetails
     """The verb to execute in this graph node."""
 
-    node_input: Union[str, dict[str, list[str]]]
+    node_input: str | dict[str, WorkflowInput | list[WorkflowInput]]
     """The input to this node."""
 
-    args: dict[str, Any] = field(default_factory=dict)
+    args: dict = field(default_factory=dict)
     """The arguments to pass to the verb."""
-
-    result: Optional[TableContainer] = None
-    """The result of executing this node."""
